aboutsummaryrefslogtreecommitdiffstats
path: root/include/text.php
diff options
context:
space:
mode:
authorAndrew Manning <tamanning@zoho.com>2016-08-17 21:25:50 -0400
committerAndrew Manning <tamanning@zoho.com>2016-08-17 21:25:50 -0400
commitf2e87a204d0a257edb501dfedaad867700c58842 (patch)
treeadf61dd77dedbb332c5e48fe0e297da54047d7f8 /include/text.php
parentc98b91f5149d53f522a19ec0f69b4d4727d34896 (diff)
downloadvolse-hubzilla-f2e87a204d0a257edb501dfedaad867700c58842.tar.gz
volse-hubzilla-f2e87a204d0a257edb501dfedaad867700c58842.tar.bz2
volse-hubzilla-f2e87a204d0a257edb501dfedaad867700c58842.zip
Progress implementing zip file export
Diffstat (limited to 'include/text.php')
-rw-r--r--include/text.php32
1 files changed, 7 insertions, 25 deletions
diff --git a/include/text.php b/include/text.php
index c8e0b1888..1729048e9 100644
--- a/include/text.php
+++ b/include/text.php
@@ -2267,11 +2267,11 @@ function design_tools() {
}
/**
* @brief Creates website import tools menu
*
* @return string
*/
-function website_import_tools() {
+function website_portation_tools() {
$channel = App::get_channel();
$sys = false;
@@ -2282,7 +2282,7 @@ function website_import_tools() {
$sys = true;
}
- return replace_macros(get_markup_template('website_import_tools.tpl'), array(
+ return replace_macros(get_markup_template('website_portation_tools.tpl'), array(
'$title' => t('Import'),
'$import_label' => t('Import website...'),
'$import_placeholder' => t('Select folder to import'),
@@ -2290,29 +2290,11 @@ function website_import_tools() {
'$file_import_text' => t('Import from cloud files:'),
'$desc' => t('/cloud/channel/path/to/folder'),
'$hint' => t('Enter path to website files'),
- '$select' => t('Select folder'),
- ));
-}
-
-/**
- * @brief Creates website export tools menu
- *
- * @return string
- */
-function website_export_tools() {
-
- $channel = App::get_channel();
- $sys = false;
-
- if(App::$is_sys && is_site_admin()) {
- require_once('include/channel.php');
- $channel = get_sys_channel();
- $sys = true;
- }
-
- return replace_macros(get_markup_template('website_export_tools.tpl'), array(
- '$title' => t('Export'),
+ '$select' => t('Select folder'),
'$export_label' => t('Export website...'),
+ '$file_download_text' => t('Export to a zip file'),
+ '$filename_desc' => t('website.zip'),
+ '$filename_hint' => t('Enter a name for the zip file.'),
));
}
@@ -2267,11 +2267,11 @@ function design_tools() {
}
/**
- * @brief Creates website import tools menu
+ * @brief Creates website portation tools menu
*
* @return string